function [M, K] = heatElem (h, V, k, a)
% function [M, K] = heatElem (h, V, k, a)
%
% return the 2x2 element mass matrix M and stiffness matrix K
% associated with a 1D diffusion problem
%   V ux - k uxx - f == 0,
% with two nodes space distance h apart.
%
% parameters:
%   h  = node spacing
%   V  = convection velocity.
%   k  = diffusion coefficient.
%   a  = Petrov-Galerkin constant.
%
% written by Robert Osada

Mn = (h/6) * [ 2  1; 1 2];
Kn = (k/h) * [ 1 -1;-1 1] + (V/2) * [-1 1;-1 1];

Mw = (h/4) * [-1 -1; 1 1] * sign(V);
Kw = (V/2) * [ 1 -1;-1 1] * sign(V);

M  = Mn + a*Mw;
K  = Kn + a*Kw;