function [M, K] = heatGlobal (x, V, k, a)
% function [M, K] = heatGlobal (x, V, k, a)
%
% assembles the global mass matrix M and stiffness matrix K
% associated with a 1D diffusion problem
%   V ux - k uxx - f == 0,
% with nodes at positions x.
%
% parameters:
%   x  = node positions.
%   V  = convection velocity.
%   k  = diffusion coefficient.
%   a  = Petrov-Galerkin constant.
%
% written by Robert Osada

n = length(x);

M = sparse(n,n);
K = sparse(n,n);

for i = [1:n-1]
   h = x(i+1) - x(i);
    
   [Melem, Kelem] = heatElem(h, V, k, a);
      
   M([i i+1],[i i+1]) = M([i i+1],[i i+1]) + Melem;
   K([i i+1],[i i+1]) = K([i i+1],[i i+1]) + Kelem;
end